@@ -21,6 +21,7 @@ from .source import (
     BaseSource,
     DeepgramSource,
     GenericSource,
+    InMemorySource,
     RevSource,
     SignedURLSource,
     VTTSource,
@@ -48,6 +49,7 @@ __all__ = [
     "DeepgramSource",
     "ExtractJob",
     "GenericSource",
+    "InMemorySource",
     "JobSettings",
     "ListJobs",
     "ListSummaries",
